(v0.12.7)=
### 0.12.7 {small}`2025-12-16`

#### Documentation

- Add cruft config & update contributors {smaller}`zethson` ({pr}`2223`)

#### Bug fixes

- Handle `pandas.options.future.infer_string` {smaller}`P Angerer` {smaller}`I Gold` ({pr}`2133`)
- Ensure there are no dangling file handles in {func}`anndata.experimental.concat_on_disk` when passing `.h5ad`-terminated strings as path inputs. {user}`ilan-gold` ({pr}`2218`)
- Ensure {attr}`anndata.experimental.backed.Dataset2D.true_index` is carried over when subsetting by columns i.,e `ds[[col1, col2]]` {user}`ilan-gold` ({pr}`2220`)
